==> foundation-2.6.1.tgz: package/BitcoinCircle/BitcoinCircle.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const BitcoinCircle = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M49.805 38.076l-2.049 8.215c2.323.579 9.483 2.941 10.643-1.708 1.209-4.847-6.271-5.928-8.594-6.507zm-3.082 12.361l-2.26 9.058c2.789.693 11.392 3.455 12.664-1.655 1.329-5.328-7.615-6.707-10.404-7.403z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M59.067 13.621C38.981 8.612 18.633 20.84 13.626 40.932c-5.011 20.089 7.216 40.438 27.3 45.447 20.092 5.009 40.44-7.217 45.449-27.307 5.009-20.091-7.217-40.443-27.308-45.451zm7.462 31.037c-.541 3.653-2.565 5.422-5.254 6.041 3.691 1.921 5.57 4.869 3.78 9.979-2.22 6.345-7.497 6.881-14.512 5.553l-1.703 6.824-4.115-1.025 1.68-6.733a156.615 156.615 0 01-3.279-.85l-1.686 6.764-4.11-1.026 1.703-6.836c-.961-.246-1.937-.508-2.933-.757l-5.354-1.336 2.042-4.709s3.032.807 2.991.747c1.165.289 1.681-.471 1.885-.978l2.691-10.787c.151.037.298.073.434.108a3.497 3.497 0 00-.427-.137l1.919-7.701c.05-.874-.251-1.976-1.917-2.392.065-.044-2.988-.743-2.988-.743l1.095-4.395 5.675 1.417-.005.021c.853.212 1.732.413 2.628.617l1.686-6.757 4.112 1.025-1.652 6.625c1.104.252 2.215.506 3.297.775l1.641-6.581 4.114 1.025-1.685 6.76c5.194 1.789 8.993 4.471 8.247 9.462z"
  })));
});
BitcoinCircle.displayName = 'BitcoinCircle';
export const BitcoinCircleDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/BitcoinCircle/BitcoinCircle.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var BitcoinCircle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M49.805 38.076l-2.049 8.215c2.323.579 9.483 2.941 10.643-1.708 1.209-4.847-6.271-5.928-8.594-6.507zm-3.082 12.361l-2.26 9.058c2.789.693 11.392 3.455 12.664-1.655 1.329-5.328-7.615-6.707-10.404-7.403z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M59.067 13.621C38.981 8.612 18.633 20.84 13.626 40.932c-5.011 20.089 7.216 40.438 27.3 45.447 20.092 5.009 40.44-7.217 45.449-27.307 5.009-20.091-7.217-40.443-27.308-45.451zm7.462 31.037c-.541 3.653-2.565 5.422-5.254 6.041 3.691 1.921 5.57 4.869 3.78 9.979-2.22 6.345-7.497 6.881-14.512 5.553l-1.703 6.824-4.115-1.025 1.68-6.733a156.615 156.615 0 01-3.279-.85l-1.686 6.764-4.11-1.026 1.703-6.836c-.961-.246-1.937-.508-2.933-.757l-5.354-1.336 2.042-4.709s3.032.807 2.991.747c1.165.289 1.681-.471 1.885-.978l2.691-10.787c.151.037.298.073.434.108a3.497 3.497 0 00-.427-.137l1.919-7.701c.05-.874-.251-1.976-1.917-2.392.065-.044-2.988-.743-2.988-.743l1.095-4.395 5.675 1.417-.005.021c.853.212 1.732.413 2.628.617l1.686-6.757 4.112 1.025-1.652 6.625c1.104.252 2.215.506 3.297.775l1.641-6.581 4.114 1.025-1.685 6.76c5.194 1.789 8.993 4.471 8.247 9.462z"
  })));
});
BitcoinCircle.displayName = 'BitcoinCircle';
export var BitcoinCircleDimensions = {
  height: 100,
  width: 100
};
